@@ -27,7 +27,7 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Henryhaoson"
     author_url = "https://git.17bdc.com/android-apps/sentry-dingtalk"
-    version = "5.0.0"
+    version = "6.0.0"
     resource_links = [
         ("Report Issue", "https://git.17bdc.com/android-apps/sentry-dingtalk/issues"),
         ("View Source", "https://git.17bdc.com/android-apps/sentry-dingtalk"),
@@ -113,7 +113,7 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"## Error: [{group.title}>>]({issue_link}) \n\n"
         payload = f"{payload} #### UserId: [{userId}](https://admin.shanbay.com/jetty/users/{userId}) \n\n"
         payload = f"{payload} #### Project: {project.name} \n\n"
-        payload = f"{payload} #### release: [{release.version}]({release.url}) \n\n"
+        payload = f"{payload} #### release: [{release}]({release.url}) \n\n"
         payload = f"{payload} #### event type: {group.get_event_type()} \n\n"
         payload = f"{payload} > Detail: {group.message} \n\n"
 
